Calculate the gamma distribution for a given sample mean
d_sample_mean_g.RdThis function calculates the probability density function of the gamma distribution for a given sample mean.

d_sample_mean_g.RdThis function calculates the probability density function of the gamma distribution for a given sample mean.