Skip to contents

Calculate the density of the sample mean for a normal distribution

Usage

d_sample_mean_n(x, n, mu, sd)

Arguments

x

The value at which to evaluate the density

n

The sample size

mu

The mean of the distribution

sd

The standard deviation of the distribution Construct control limits using echarts4r

Value

The density of the sample mean

Examples

d_sample_mean_n(x = 2, n = 10, mu = 0, sd = 1)
#> [1] 2.600282e-09