Skip to contents

This function calculates various statistical measures for the inverse Gaussian control chart.

Usage

stats_ig(data, alpha = 0.0027, mu = NULL, lambda = NULL, ...)

Arguments

data

The data matrix.

alpha

The significance level.

mu

The mean parameter of the distribution (optional).

lambda

The shape parameter of the distribution (optional).

...

Additional arguments to be passed to the limits function.

Value

A list containing the estimated parameters, alpha-hat, ARL, MRL, SDRL, control limits, convergence status, and value of the objective function.

Examples

set.seed(0)
x <- r_ig(lots = 1000, n = 10, mu = 1, lambda = 1.7)

# Estimate for maximum likelihood
stats_ig(data = x)
#> $mu_hat
#> [1] 0.9923649
#> 
#> $lambda_hat
#> [1] 1.861464
#> 
#> $alpha_hat
#> [1] 0
#> 
#> $ARL
#> [1] Inf
#> 
#> $MRL
#> [1] -Inf
#> 
#> $SDRL
#> [1] Inf
#> 
#> $li
#> [1] 0.4929123
#> 
#> $ls
#> [1] 1.902939
#> 
#> $convergence
#> [1] 0
#> 
#> $value
#> [1] -93.64581
#> 

# Using the true parameters
stats_ig(data = x, mu = 1, lambda = 1.7)
#> $mu_hat
#> [1] 1
#> 
#> $lambda_hat
#> [1] 1.7
#> 
#> $alpha_hat
#> [1] 0
#> 
#> $ARL
#> [1] Inf
#> 
#> $MRL
#> [1] -Inf
#> 
#> $SDRL
#> [1] Inf
#> 
#> $li
#> [1] 0.4798106
#> 
#> $ls
#> [1] 1.97604
#> 
#> $convergence
#> NULL
#> 
#> $value
#> NULL
#>